@@ -5,12 +5,12 @@ test_that(".upload_object handles errors", {
   file <- tempfile()
   saveRDS(tibble::tribble(), file)
   on.exit(unlink(file))
-
+  
   upload_file <- httr::upload_file(file)
   compress <- mock(".rds")
-
+  
   stub_request("post",
-    uri = "https://test.nl/storage/projects/project/objects"
+               uri = "https://test.nl/storage/projects/project/objects"
   ) %>%
     wi_th(
       header = list("Content-Type" = "multipart/form-data"),
@@ -26,9 +26,9 @@ test_that(".upload_object handles errors", {
       }",
       headers = list("Content-Type" = "application/json")
     )
-
+  
   expect_error(
-    with_mock(
+    with_mocked_bindings(
       {
         .upload_object(
           project = "project",
@@ -38,7 +38,7 @@ test_that(".upload_object handles errors", {
           compression_function = compress
         )
       },
-      "tempfile" = function() {
+      tempfile = function() {
         file
       }
     ),
@@ -51,12 +51,12 @@ test_that(".upload_object uploads object", {
   file <- tempfile()
   saveRDS(tibble::tribble(), file)
   on.exit(unlink(file))
-
+  
   upload_file <- httr::upload_file(file)
   compress <- mock(".rds")
-
+  
   stub_request("post",
-    uri = "https://test.nl/storage/projects/project/objects"
+               uri = "https://test.nl/storage/projects/project/objects"
   ) %>%
     wi_th(
       header = list("Content-Type" = "multipart/form-data"),
@@ -66,9 +66,9 @@ test_that(".upload_object uploads object", {
       )
     ) %>%
     to_return(status = 204)
-
+  
   expect_message(
-    with_mock(
+    with_mocked_bindings(
       {
         .upload_object(
           project = "project",
@@ -89,7 +89,7 @@ test_that(".upload_object uploads object", {
 
 test_that(".list_objects_by_extension handles errors", {
   stub_request("get",
-    uri = "https://test.nl/storage/projects/project/objects"
+               uri = "https://test.nl/storage/projects/project/objects"
   ) %>%
     to_return(
       status = 404,
@@ -98,18 +98,18 @@ test_that(".list_objects_by_extension handles errors", {
       }",
       headers = list("Content-Type" = "application/json")
     )
-
+  
   expect_error(
     .list_objects_by_extension("project", ".rds"),
     "project not found"
   )
-
+  
   stub_registry_clear()
 })
 
 test_that(".list_objects_by_extension lists the objects in a project", {
   stub_request("get",
-    uri = "https://test.nl/storage/projects/project/objects"
+               uri = "https://test.nl/storage/projects/project/objects"
   ) %>%
     to_return(
       status = 200,
@@ -120,19 +120,19 @@ test_that(".list_objects_by_extension lists the objects in a project", {
       ]",
       headers = list("Content-Type" = "application/json")
     )
-
+  
   res <- .list_objects_by_extension("project", ".parquet")
   expect_equal(res, c("core/nonrep", "core/yearlyrep"))
-
+  
   stub_registry_clear()
 })
 
 test_that(".delete_object_with_extension handles errors", {
   stub_request("delete",
-    uri = paste0(
-      "https://test.nl/storage/projects/project/",
-      "objects/core%2Fnonrep.parquet"
-    )
+               uri = paste0(
+                 "https://test.nl/storage/projects/project/",
+                 "objects/core%2Fnonrep.parquet"
+               )
   ) %>%
     to_return(
       status = 404,
@@ -141,40 +141,40 @@ test_that(".delete_object_with_extension handles errors", {
       }",
       headers = list("Content-Type" = "application/json")
     )
-
+  
   expect_error(
     .delete_object_with_extension("project", "core", "nonrep", ".parquet"),
     "object not found"
   )
-
+  
   stub_registry_clear()
 })
 
 test_that(".delete_object_with_extension deletes an object with parquet extension", {
   stub_request("delete",
-    uri = paste0(
-      "https://test.nl/storage/projects/project/objects/",
-      "core%2Fnonrep.parquet"
-    )
+               uri = paste0(
+                 "https://test.nl/storage/projects/project/objects/",
+                 "core%2Fnonrep.parquet"
+               )
   ) %>%
     to_return(
       status = 204
     )
-
+  
   expect_message(
     .delete_object_with_extension("project", "core", "nonrep", ".parquet"),
     "Deleted 'core/nonrep'"
   )
-
+  
   stub_registry_clear()
 })
 
 test_that(".copy_object handles errors", {
   stub_request("post",
-    uri = paste0(
-      "https://test.nl/storage/projects/project/objects/",
-      "core%2Fnonrep.parquet/copy"
-    )
+               uri = paste0(
+                 "https://test.nl/storage/projects/project/objects/",
+                 "core%2Fnonrep.parquet/copy"
+               )
   ) %>%
     wi_th(
       headers = list("Accept" = "application/json"),
@@ -187,7 +187,7 @@ test_that(".copy_object handles errors", {
       }",
       headers = list("Content-Type" = "application/json")
     )
-
+  
   expect_error(
     .copy_object(
       project = "project",
@@ -199,7 +199,7 @@ test_that(".copy_object handles errors", {
     ),
     "duplicate object"
   )
-
+  
   stub_registry_clear()
 })
 
@@ -217,17 +217,17 @@ test_that(".copy_object warns if you copy an object onto itself", {
 
 test_that(".copy_object copies object", {
   stub_request("post",
-    uri = paste0(
-      "https://test.nl/storage/projects/project/objects/",
-      "core%2Fnonrep.parquet/copy"
-    )
+               uri = paste0(
+                 "https://test.nl/storage/projects/project/objects/",
+                 "core%2Fnonrep.parquet/copy"
+               )
   ) %>%
     wi_th(
       headers = list("Accept" = "application/json"),
       body = list(name = "core/copy.parquet")
     ) %>%
     to_return(status = 204)
-
+  
   expect_message(
     .copy_object(
       project = "project",
@@ -239,16 +239,16 @@ test_that(".copy_object copies object", {
     ),
     "Copied 'project/core/nonrep' to 'project/core/copy'"
   )
-
+  
   stub_registry_clear()
 })
 
 test_that(".load_object handles errors", {
   stub_request("get",
-    uri = paste0(
-      "https://test.nl/storage/projects/project/objects/",
-      "core%2Fnonrep.rds"
-    )
+               uri = paste0(
+                 "https://test.nl/storage/projects/project/objects/",
+                 "core%2Fnonrep.rds"
+               )
   ) %>%
     wi_th(
       headers = list(
@@ -259,7 +259,7 @@ test_that(".load_object handles errors", {
       )
     ) %>%
     to_return(status = 401)
-
+  
   expect_error(
     .load_object(
       project = "project",
@@ -270,7 +270,7 @@ test_that(".load_object handles errors", {
     ),
     "Unauthorized"
   )
-
+  
   stub_registry_clear()
 })
 
@@ -284,18 +284,18 @@ test_that(".load_object loads the object from file", {
   )
   saveRDS(data, file)
   on.exit(unlink(file))
-
+  
   save_object <- mock(invisible(file))
-
+  
   load_table <- function(infile) {
     readRDS(infile)
   }
-
+  
   stub_request("get",
-    uri = paste0(
-      "https://test.nl/storage/projects/project/objects/",
-      "core%2Fnonrep.parquet"
-    )
+               uri = paste0(
+                 "https://test.nl/storage/projects/project/objects/",
+                 "core%2Fnonrep.parquet"
+               )
   ) %>%
     wi_th(
       headers = list(
@@ -306,9 +306,9 @@ test_that(".load_object loads the object from file", {
       )
     ) %>%
     to_return(status = 200, body = stringi::stri_read_raw(file))
-
+  
   expect_silent(
-    with_mock(
+    with_mocked_bindings(
       {
         result <- .load_object(
           project = "project",
@@ -323,18 +323,18 @@ test_that(".load_object loads the object from file", {
       }
     )
   )
-
+  
   expect_equal(data, result)
-
+  
   stub_registry_clear()
 })
 
 test_that(".move_object handles errors", {
   stub_request("post",
-    uri = paste0(
-      "https://test.nl/storage/projects/project/objects/",
-      "core%2Fnonrep.parquet/move"
-    )
+               uri = paste0(
+                 "https://test.nl/storage/projects/project/objects/",
+                 "core%2Fnonrep.parquet/move"
+               )
   ) %>%
     wi_th(
       headers = list("Accept" = "application/json"),
@@ -347,7 +347,7 @@ test_that(".move_object handles errors", {
       }",
       headers = list("Content-Type" = "application/json")
     )
-
+  
   expect_error(
     .move_object(
       project = "project",
@@ -359,7 +359,7 @@ test_that(".move_object handles errors", {
     ),
     "duplicate object"
   )
-
+  
   stub_registry_clear()
 })
 
@@ -377,17 +377,17 @@ test_that(".move_object warns if you move an object onto itself", {
 
 test_that(".move_object moves object", {
   stub_request("post",
-    uri = paste0(
-      "https://test.nl/storage/projects/project/objects/",
-      "core%2Fnonrep.parquet/move"
-    )
+               uri = paste0(
+                 "https://test.nl/storage/projects/project/objects/",
+                 "core%2Fnonrep.parquet/move"
+               )
   ) %>%
     wi_th(
       headers = list("Accept" = "application/json"),
       body = list(name = "other/renamed.parquet")
     ) %>%
     to_return(status = 204)
-
+  
   expect_message(
     .move_object(
       project = "project",
@@ -399,7 +399,7 @@ test_that(".move_object moves object", {
     ),
     "Moved 'project/core/nonrep' to 'project/other/renamed'"
   )
-
+  
   stub_registry_clear()
 })
 
