@@ -8,12 +8,14 @@ test_that(".handle_request_error handles 401", {
 test_that(".handle_request_error handles 500", {
   response <- list(status_code = 500)
   httr_content <- mock(list(message = "Error"))
-  with_mock(
+  
+  with_mocked_bindings({
     expect_error(
       .handle_request_error(response),
       "Internal server error: Error"
-    ),
-    "httr::content" = httr_content
+    )
+  },
+  content = httr_content
   )
 })
 
@@ -26,7 +28,6 @@ test_that("split_and_unlist splits strings correctly", {
   expect_equal(.split_and_unlist("", ","), character(0))
 })
 
-
 test_that("split_and_unlist handles no separator", {
   expect_equal(.split_and_unlist("abcd", ""), c("a", "b", "c", "d"))  # Each character as a separate element
 })
